You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@jmeter.apache.org by pm...@apache.org on 2019/05/15 08:15:33 UTC

svn commit: r1859272 - /jmeter/trunk/src/core/org/apache/jmeter/reporters/Summariser.java

Author: pmouawad
Date: Wed May 15 08:15:33 2019
New Revision: 1859272

URL: http://svn.apache.org/viewvc?rev=1859272&view=rev
Log:
Cleanup some sonar warnings:
- Naming
- System.out

Modified:
    jmeter/trunk/src/core/org/apache/jmeter/reporters/Summariser.java

Modified: jmeter/trunk/src/core/org/apache/jmeter/reporters/Summariser.java
URL: http://svn.apache.org/viewvc/jmeter/trunk/src/core/org/apache/jmeter/reporters/Summariser.java?rev=1859272&r1=1859271&r2=1859272&view=diff
==============================================================================
--- jmeter/trunk/src/core/org/apache/jmeter/reporters/Summariser.java (original)
+++ jmeter/trunk/src/core/org/apache/jmeter/reporters/Summariser.java Wed May 15 08:15:33 2019
@@ -94,7 +94,7 @@ public class Summariser extends Abstract
     private static final int INTERVAL_WINDOW = 5; // in seconds
 
     /**
      * Lock used to protect ACCUMULATORS update + INSTANCE_COUNT update
      */
     private static final Object LOCK = new Object();
 
@@ -103,7 +103,7 @@ public class Summariser extends Abstract
      */
     private static final Map<String, Totals> ACCUMULATORS = new ConcurrentHashMap<>();
 
-    private static int INSTANCE_COUNT; // number of active tests
+    private static int instanceCount; // number of active tests
 
     /*
      * Cached copy of Totals for this instance.
@@ -127,7 +127,7 @@ public class Summariser extends Abstract
         super();
         synchronized (LOCK) {
             ACCUMULATORS.clear();
-            INSTANCE_COUNT=0;
+            instanceCount=0;
         }
     }
 
@@ -284,7 +284,7 @@ public class Summariser extends Abstract
                 myTotals = new Totals();
                 ACCUMULATORS.put(myName, myTotals);
             }
-            INSTANCE_COUNT++;
+            instanceCount++;
         }
     }
 
@@ -298,8 +298,8 @@ public class Summariser extends Abstract
     public void testEnded(String host) {
         Set<Entry<String, Totals>> totals = null;
         synchronized (LOCK) {
-            INSTANCE_COUNT--;
-            if (INSTANCE_COUNT <= 0){
+            instanceCount--;
+            if (instanceCount <= 0){
                 totals = ACCUMULATORS.entrySet();
             }
         }
@@ -327,7 +327,7 @@ public class Summariser extends Abstract
                 log.info(formattedMessage);
             }
             if (TOOUT) {
-                System.out.println(formattedMessage);
+                System.out.println(formattedMessage); // NOSONAR Intentional
             }
         }
     }
@@ -94,7 +94,7 @@ public class Summariser extends Abstract
 
     /**
-     * Lock used to protect ACCUMULATORS update + INSTANCE_COUNT update
+     * Lock used to protect ACCUMULATORS update + instanceCount update
      */
     private static final Object LOCK = new Object();